# `simpandas`
A couple of Pandas DataFrame and Series subclasses, extended to work with units and to deal with column names following the style of eclipse simulator outputs.

This package is under development and is regularly updated. Back-compatibility is intended to be maintained when possible.

## What Contains This Package
It is powered by other packages, like <a href="https://numpy.org/">**NumPy**</a>, <a href="https://seaborn.pydata.org/">**seaborn**</a> and <a href="https://github.com/ayaranitram/unyts">**unyts**</a> and further own methods, to be able to deal with tables of quantities and facilitate common manipulations of time-dependent data.

## To install this package:
To install it from the <a href="https://pypi.org/search/?q=simpandas">pypi.org</a> repository:  
`pip install simpandas`
or upgrade to the latest version:
`pip install --upgrade simpandas`

## Requisites
- Pandas
- NumPy
- matplotlib
- datetime
- unyts
